<?php
session_start();
if (!isset($_SESSION['user'])) {
    exit('❌ 无权限访问');
}

// 引入数据库配置文件
require_once '../config.php';

// 数据库连接
$conn = get_db_connection();

// 检查是否为POST请求
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    exit('❌ 无效的请求方法');
}

// 获取表单数据
$action = $_POST['action'] ?? '';
$name = trim($_POST['name'] ?? '');
$contact_person = trim($_POST['contact_person'] ?? '');
$phone = trim($_POST['phone'] ?? '');
$address = trim($_POST['address'] ?? '');

// 验证必填字段
if (empty($name)) {
    exit('❌ 供应商名称不能为空');
}

try {
    if ($action === 'add') {
        // 添加新供应商
        $stmt = $conn->prepare("INSERT INTO suppliers (name, contact_person, phone, address) VALUES (?, ?, ?, ?)");
        $stmt->bind_param("ssss", $name, $contact_person, $phone, $address);

        if ($stmt->execute()) {
            echo "✅ 供应商添加成功！";
        } else {
            throw new Exception("添加失败：" . $stmt->error);
        }
    } elseif ($action === 'edit') {
        // 更新供应商
        $id = (int)$_POST['id'];
        if ($id <= 0) {
            throw new Exception("无效的供应商ID");
        }

        $stmt = $conn->prepare("UPDATE suppliers SET name = ?, contact_person = ?, phone = ?, address = ? WHERE id = ?");
        $stmt->bind_param("ssssi", $name, $contact_person, $phone, $address, $id);

        if ($stmt->execute()) {
            echo "✅ 供应商更新成功！";
        } else {
            throw new Exception("更新失败：" . $stmt->error);
        }
    } else {
        throw new Exception("无效的操作类型");
    }
} catch (Exception $e) {
    echo "❌ " . $e->getMessage();
} finally {
    if (isset($stmt)) {
        $stmt->close();
    }
    $conn->close();
}
