<?php
// add_product.php
// 引入数据库配置文件
require_once '../config.php';

// 数据库连接
$conn = get_db_connection();

// 生成自增商品编号
$nextCode = "SP001";
$codeQuery = "SELECT product_code FROM products ORDER BY id DESC LIMIT 1";
$codeResult = $conn->query($codeQuery);
if ($codeResult && $codeResult->num_rows > 0) {
    $lastCode = $codeResult->fetch_assoc()['product_code'];
    if (preg_match('/^SP(\d+)$/', $lastCode, $matches)) {
        $nextNum = intval($matches[1]) + 1;
        $nextCode = 'SP' . str_pad($nextNum, 3, '0', STR_PAD_LEFT);
    }
}

// 查询分类、仓库、供应商
$categories = $conn->query("SELECT id, name FROM categories ORDER BY id");
$warehouses = $conn->query("SELECT id, name FROM warehouses ORDER BY id");
$suppliers = $conn->query("SELECT id, name FROM suppliers ORDER BY id");
?>

<!DOCTYPE html>
<html lang="zh">

<head>
    <meta charset="UTF-8">
    <title>新增商品</title>
    <link rel="stylesheet" href="style.css">
    <!-- 消息容器 -->
    <div id="message-container"></div>
    <style>
        .multi-unit-table,
        .unit-ratio-input,
        .unit-display,
        .unit-input-display-row,
        .unit-ratios-container,
        .unit-ratio-item {
            width: 100%;
            border-collapse: collapse;
            margin-top: 10px;
        }

        .multi-unit-table th,
        .multi-unit-table td {
            border: 1px solid #ccc;
            padding: 6px 10px;
            text-align: center;
        }

        .multi-unit-table th {
            background-color: #f8f8f8;
        }

        .unit-ratio-input {
            display: flex;
            margin-bottom: 10px;
            flex: 1;
        }

        .unit-ratio-input input {
            flex: 1;
            margin-right: 10px;
        }

        .unit-ratio-input select {
            width: 120px;
        }

        .unit-display {
            font-weight: bold;
            margin-bottom: 10px;
            min-height: 24px;
            padding: 5px 10px;
            border: 1px dashed #ccc;
            border-radius: 4px;
            background-color: #f9f9f9;
            min-width: 150px;
            margin-left: 15px;
            display: flex;
            align-items: center;
            justify-content: center;
            color: #2b9348;
        }

        .unit-input-display-row {
            display: flex;
            align-items: center;
            margin-bottom: 10px;
        }

        .unit-ratio-item {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 5px;
            padding: 8px;
            background-color: #f5f5f5;
            border-radius: 4px;
            border: 1px solid #e0e0e0;
        }

        .unit-ratio-item .delete-ratio {
            background-color: #ff6b6b;
            color: white;
            border: none;
            border-radius: 50%;
            width: 24px;
            height: 24px;
            cursor: pointer;
            display: flex;
            align-items: center;
            justify-content: center;
            font-weight: bold;
        }

        .unit-ratio-item .delete-ratio:hover {
            background-color: #ff5252;
        }

        /* 价格策略表格样式 */
        #price-strategy-table {
            width: 100%;
            border-collapse: collapse;
            margin: 15px 0 20px 0;
            table-layout: fixed;
        }

        #price-strategy-table th,
        #price-strategy-table td {
            border: 1px solid #ddd;
            padding: 4px;
            text-align: center;
            font-size: 14px;
            word-wrap: break-word;
            overflow: hidden;
        }

        /* 调整各列的宽度百分比 */
        #price-strategy-table th:nth-child(1) {
            width: 8%;
        }

        #price-strategy-table th:nth-child(2) {
            width: 8%;
        }

        #price-strategy-table th:nth-child(3) {
            width: 11%;
        }

        #price-strategy-table th:nth-child(4) {
            width: 11%;
        }

        #price-strategy-table th:nth-child(5) {
            width: 11%;
        }

        #price-strategy-table th:nth-child(6) {
            width: 11%;
        }

        #price-strategy-table th:nth-child(7) {
            width: 12%;
        }

        #price-strategy-table th:nth-child(8) {
            width: 12%;
        }

        #price-strategy-table th:nth-child(9) {
            width: 12%;
        }

        #price-strategy-table th {
            background-color: #f5f5f5;
            font-weight: bold;
            color: #444;
            white-space: nowrap;
            font-size: 13px;
        }

        #price-strategy-table tr:nth-child(even) {
            background-color: #fafafa;
        }

        #price-strategy-table tr:hover {
            background-color: #f0f7f0;
        }

        #price-strategy-table input[type="number"]::-webkit-inner-spin-button,
        #price-strategy-table input[type="number"]::-webkit-outer-spin-button {
            -webkit-appearance: none;
            margin: 0;
        }

        #price-strategy-table input[type="number"],
        #price-strategy-table input[type="text"] {
            width: 100%;
            padding: 3px 2px;
            border: none;
            background: transparent;
            text-align: center;
            box-sizing: border-box;
            height: 26px;
            margin: 0;
            font-size: 13px;
        }

        #price-strategy-table input[type="number"],
        #price-strategy-table input[type="text"] {
            appearance: textfield;
            -webkit-appearance: textfield;
            -moz-appearance: textfield;
        }

        #price-strategy-table td {
            position: relative;
            padding: 0;
        }

        #price-strategy-table input[type="number"]:focus,
        #price-strategy-table input[type="text"]:focus {
            outline: 2px solid #2b9348;
            background-color: rgba(43, 147, 72, 0.05);
            box-shadow: none;
            position: relative;
            z-index: 1;
        }

        #price-strategy-table td:nth-child(8),
        #price-strategy-table td:nth-child(9) {
            background-color: #f9f9f9;
        }

        #price-strategy-table tr#base-unit-row {
            background-color: #f5f9f5;
            font-weight: bold;
        }

        #price-strategy-table tr[id^="sub-unit-row"] {
            background-color: #fcfcfc;
        }

        #price-strategy-container {
            width: 100%;
            overflow-x: visible;
            padding-bottom: 10px;
            border: none;
            margin-bottom: 20px;
        }

        #price-strategy-table td:first-child,
        #price-strategy-table td:nth-child(2),
        #price-strategy-table td:nth-child(3) {
            padding: 4px 2px;
            font-weight: normal;
            font-size: 13px;
        }

        #price-strategy-table td:nth-child(3) {
            color: #444;
            background-color: #f7f7f7;
        }

        #price-strategy-table tr#base-unit-row td:first-child {
            font-weight: bold;
            color: #2b9348;
        }

        #price-strategy-table tr[id^="sub-unit-row"] td:first-child {
            color: #555;
        }

        #price-strategy-table th {
            padding: 6px 2px;
            font-size: 12px;
            letter-spacing: -0.5px;
        }
    </style>
</head>

<body>
    <div class="header">
        <h2>新增商品</h2>
        <a href="list_products.php" class="btn btn-secondary">返回列表</a>
    </div>
    <div class="container">
        <form action="save_product.php" method="post" enctype="multipart/form-data" target="response-frame" id="product-form">
            <div class="form-group">
                <label>商品编号:</label>
                <input type="text" name="product_code" value="<?= $nextCode ?>">
            </div>

            <div class="form-group">
                <label>商品名称:</label>
                <input type="text" name="product_name">
            </div>

            <div class="form-row">
                <div class="form-col">
                    <label>商品类别:</label>
                    <select name="category_id">
                        <option value="">请选择类别</option>
                        <?php while ($row = $categories->fetch_assoc()): ?>
                            <option value="<?= $row['id'] ?>"><?= htmlspecialchars($row['name']) ?></option>
                        <?php endwhile; ?>
                    </select>
                </div>
                <div class="form-col">
                    <label>商品条码:</label>
                    <input type="text" name="barcode">
                </div>
            </div>

            <div class="form-row">
                <div class="form-col">
                    <label>规格型号:</label>
                    <input type="text" name="specification">
                </div>
                <div class="form-col">
                    <label>首选仓库:</label>
                    <select name="warehouse_id">
                        <option value="">(空)</option>
                        <?php while ($row = $warehouses->fetch_assoc()): ?>
                            <option value="<?= $row['id'] ?>"><?= htmlspecialchars($row['name']) ?></option>
                        <?php endwhile; ?>
                    </select>
                </div>
            </div>

            <div class="form-row">
                <div class="form-col form-col-checkbox">
                    <label>多单位:</label>
                    <input type="checkbox" name="multi_unit" id="multi_unit_checkbox" value="1">
                </div>
                <div class="form-col">
                    <label>基本单位:</label>
                    <!-- 基本单位选择框（未勾选多单位时显示） -->
                    <div id="simple_unit_container">
                        <select name="unit" id="unit_select">
                            <option value="">请选择单位</option>
                            <option value="支">支</option>
                            <option value="盒">盒</option>
                            <option value="箱">箱</option>
                        </select>
                    </div>

                    <!-- 多单位输入区域（勾选多单位时显示） -->
                    <div id="multi_unit_container" style="display: none;">
                        <div class="unit-input-display-row">
                            <div class="unit-ratio-input">
                                <input type="text" id="unit_ratio_input" placeholder="输入如 1,20,30">
                                <select id="unit_combo_select" style="display: none;">
                                    <option value="">选择单位组合</option>
                                    <option value="盒,支">盒,支</option>
                                    <option value="箱,盒">箱,盒</option>
                                    <option value="箱,支">箱,支</option>
                                </select>
                            </div>
                            <div id="unit_display" class="unit-display"></div>
                        </div>

                        <div id="unit_ratios_container" class="unit-ratios-container"></div>
                        <!-- 隐藏字段存储单位配比数据 -->
                        <input type="hidden" name="unit_ratios" id="unit_ratios_data">
                    </div>
                </div>
            </div>

            <div class="form-row">
                <div class="form-col">
                    <label>首选入库单位:</label>
                    <select name="preferred_in_unit">
                        <option value="">(空)</option>
                        <option value="支">支</option>
                        <option value="盒">盒</option>
                        <option value="箱">箱</option>
                    </select>
                </div>
                <div class="form-col">
                    <label>首选出库单位:</label>
                    <select name="preferred_out_unit">
                        <option value="">(空)</option>
                        <option value="支">支</option>
                        <option value="盒">盒</option>
                        <option value="箱">箱</option>
                    </select>
                </div>
            </div>

            <div class="form-row">
                <div class="form-col">
                    <label>产地:</label>
                    <input type="text" name="origin">
                </div>
                <div class="form-col">
                    <label>注册证号:</label>
                    <input type="text" name="registration_number">
                </div>
            </div>

            <div class="form-row">
                <div class="form-col">
                    <label>品牌:</label>
                    <input type="text" name="brand">
                </div>
                <div class="form-col">
                    <label>PLU码:</label>
                    <input type="number" name="plu_code">
                </div>
            </div>

            <div class="form-row">
                <div class="form-col">
                    <label>默认供应商:</label>
                    <select name="supplier_id">
                        <option value="">(空)</option>
                        <?php while ($row = $suppliers->fetch_assoc()): ?>
                            <option value="<?= $row['id'] ?>"><?= htmlspecialchars($row['name']) ?></option>
                        <?php endwhile; ?>
                    </select>
                </div>
                <div class="form-col">
                    <label>重量(kg):</label>
                    <input type="number" step="0.01" name="weight">
                </div>
            </div>

            <div class="form-group">
                <label>尺寸(长宽高):</label>
                <input type="number" step="0.01" name="length" placeholder="长">
                <input type="number" step="0.01" name="width" placeholder="宽">
                <input type="number" step="0.01" name="height" placeholder="高">
                <select disabled>
                    <option>cm</option>
                </select>
            </div>

            <h3>价格策略</h3>

            <div class="form-group form-col-checkbox">
                <label>价格策略:</label>
                <input type="checkbox" name="price_strategy_enabled" value="1" id="price_strategy_enabled" checked> 启用
            </div>

            <div id="price-strategy-container">
                <table class="multi-unit-table" id="price-strategy-table">
                    <thead>
                        <tr>
                            <th>类型</th>
                            <th>计量单位</th>
                            <th>换算公式</th>
                            <th>包装条码</th>
                            <th>零售价</th>
                            <th>批发价</th>
                            <th>VIP会员价</th>
                            <th>折扣率1(%)</th>
                            <th>折扣率2(%)</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr id="base-unit-row">
                            <td>基本单位</td>
                            <td id="base-unit-cell">支</td>
                            <td>1<span id="base-unit-name">支</span></td>
                            <td><input type="text" name="barcode" value=""></td>
                            <td><input type="number" step="0.01" name="retail_price"></td>
                            <td><input type="number" step="0.01" name="wholesale_price"></td>
                            <td><input type="number" step="0.01" name="vip_price"></td>
                            <td><input type="number" step="0.01" name="discount1"></td>
                            <td><input type="number" step="0.01" name="discount2"></td>
                        </tr>
                        <!-- 副单位行将由JavaScript动态生成 -->
                    </tbody>
                </table>
            </div>

            <div class="form-row">
                <div class="form-col">
                    <label>最低销售价:</label>
                    <input type="number" step="0.01" name="min_sale_price">
                </div>
                <div class="form-col">
                    <label>预计采购价:</label>
                    <input type="number" step="0.01" name="estimated_purchase_price">
                </div>
                <div class="form-col">
                    <label>最高采购价:</label>
                    <input type="number" step="0.01" name="max_purchase_price">
                </div>
            </div>

            <h3>开发票信息</h3>

            <div class="form-row">
                <div class="form-col">
                    <label>商品税率(%):</label>
                    <input type="number" step="0.01" name="tax_rate">
                </div>
                <div class="form-col">
                    <label>税收分类编码:</label>
                    <input type="text" name="tax_code">
                </div>
            </div>

            <div class="form-row">
                <div class="form-col">
                    <label>是否免税:</label>
                    <select name="is_tax_exempt">
                        <option value="0">否</option>
                        <option value="1">是</option>
                    </select>
                </div>
                <div class="form-col">
                    <label>商品开票名称:</label>
                    <input type="text" name="invoice_name">
                </div>
            </div>

            <h3>备注</h3>

            <div class="form-group">
                <label>备注信息:</label>
                <textarea name="remarks"></textarea>
            </div>
            <h3>商品图片</h3>
            <div class="form-group">
                <label>上传商品图片:</label>
                <input type="file" name="product_images[]" multiple accept="image/*" id="product-images">
                <small>最多上传 20 张图片，支持 JPG/PNG/JPEG 格式</small>
            </div>

            <!-- 添加图片预览区域 -->
            <div class="image-preview">
                <div class="image-grid" id="image-preview-container"></div>
            </div>

            <!-- 添加隐藏字段，用于存储已删除的图片索引 -->
            <input type="hidden" name="deleted-image-indexes" id="deleted-image-indexes" value="">

            <div class="btn-group">
                <button type="reset" class="btn btn-secondary">清空</button>
                <button type="submit" class="btn">保存</button>
                <div class="batch-add-option">
                    <input type="checkbox" id="batch_add" name="batch_add" value="1">
                    <label for="batch_add">批量添加</label>
                </div>
            </div>
        </form>
    </div>

    <!-- 添加消息显示区域 -->
    <div id="message-container" class="message" style="display: none;">
        <span id="message-text"></span>
        <button onclick="this.parentElement.style.display='none'">×</button>
    </div>

    <!-- 隐藏的iframe用于接收表单提交响应 -->
    <iframe name="response-frame" id="response-frame" style="display:none;"></iframe>

    <script>
        // 消息显示函数
        function showMessage(message, type = 'success') {
            const messageContainer = document.getElementById('message-container');
            messageContainer.innerHTML = `
                <div class="message">
                    <span>${message}</span>
                    <button onclick="this.parentElement.remove()">×</button>
                </div>
            `;

            // 3秒后自动消失
            setTimeout(() => {
                const messageElement = messageContainer.querySelector('.message');
                if (messageElement) {
                    messageElement.remove();
                }
            }, 3000);
        }

        // 检查URL参数是否包含消息
        const urlParams = new URLSearchParams(window.location.search);
        const message = urlParams.get('message');
        const type = urlParams.get('type') || 'success';

        if (message) {
            showMessage(decodeURIComponent(message), type);
        }

        // 初始化删除图片索引数组
        const deletedImageIndexes = [];

        // 页面加载完成后初始化
        document.addEventListener('DOMContentLoaded', function() {
            const urlParamsBatchAdd = new URLSearchParams(window.location.search);
            if (urlParamsBatchAdd.has('batch_add')) {
                document.getElementById('batch_add').checked = true;
                if (urlParamsBatchAdd.has('message')) showMessage(urlParamsBatchAdd.get('message'));
            }
            initMultiUnitInput();
            initUnitAutoFill();

            // 在表单提交前将已删除的图片索引添加到隐藏字段
            document.getElementById('product-form').addEventListener('submit', function() {
                document.getElementById('deleted-image-indexes').value = JSON.stringify(deletedImageIndexes);
            });
        });

        function initMultiUnitInput() {
            const multiUnitCheckbox = document.getElementById('multi_unit_checkbox');
            const simpleUnitContainer = document.getElementById('simple_unit_container');
            const multiUnitContainer = document.getElementById('multi_unit_container');
            const unitSelect = document.getElementById('unit_select');
            const unitRatioInput = document.getElementById('unit_ratio_input');
            const unitComboSelect = document.getElementById('unit_combo_select');
            const unitDisplay = document.getElementById('unit_display');
            const unitRatiosContainer = document.getElementById('unit_ratios_container');
            const unitRatiosData = document.getElementById('unit_ratios_data');
            const baseUnitCell = document.getElementById('base-unit-cell');
            const baseUnitName = document.getElementById('base-unit-name');
            const priceStrategyTable = document.getElementById('price-strategy-table');
            let unitRatios = [];

            function getAllUnits() {
                const units = [];
                for (let i = 0; i < unitSelect.options.length; i++) {
                    if (unitSelect.options[i].value) units.push(unitSelect.options[i].value);
                }
                return units;
            }

            multiUnitCheckbox.addEventListener('change', function() {
                if (this.checked) {
                    simpleUnitContainer.style.display = 'none';
                    multiUnitContainer.style.display = 'block';
                    if (unitSelect.value) {
                        unitDisplay.textContent = unitSelect.value;
                        updatePriceStrategyTable(unitSelect.value);
                    }
                    unitRatioInput.disabled = false;
                    unitRatioInput.placeholder = "输入如 1,20 或 1,20,30";
                } else {
                    simpleUnitContainer.style.display = 'block';
                    multiUnitContainer.style.display = 'none';
                    unitRatios = [];
                    unitRatiosContainer.innerHTML = '';
                    unitRatiosData.value = '';
                    unitDisplay.textContent = '';
                    updatePriceStrategyTable(unitSelect.value);
                    removeAllSubUnitRows();
                    unitRatioInput.disabled = false;
                    unitRatioInput.placeholder = "输入如 1,20 或 1,20,30";
                }
            });

            unitRatioInput.addEventListener('input', function() {
                const value = this.value.trim();
                const ratioPattern = /^\d+(,\d+)+$/;
                if (ratioPattern.test(value)) {
                    generateUnitCombinations();
                    unitComboSelect.style.display = 'block';
                } else {
                    unitComboSelect.style.display = 'none';
                }
            });

            function generateUnitCombinations() {
                const units = getAllUnits();
                unitComboSelect.innerHTML = '<option value="">选择单位组合</option>';
                const values = unitRatioInput.value.trim().split(',');

                if (values.length === 2) {
                    for (let i = 0; i < units.length; i++) {
                        for (let j = 0; j < units.length; j++) {
                            if (i !== j) {
                                const option = document.createElement('option');
                                option.value = `${units[i]},${units[j]}`;
                                option.textContent = `${units[i]},${units[j]}`;
                                unitComboSelect.appendChild(option);
                            }
                        }
                    }
                } else if (values.length === 3) {
                    const standardOrder = ["支", "盒", "箱"];
                    if (standardOrder.every(unit => units.includes(unit))) {
                        const standardOption = document.createElement('option');
                        standardOption.value = standardOrder.join(',');
                        standardOption.textContent = `${standardOrder.join(',')} (推荐)`;
                        unitComboSelect.appendChild(standardOption);
                    }

                    for (let i = 0; i < units.length; i++) {
                        for (let j = 0; j < units.length; j++) {
                            for (let k = 0; k < units.length; k++) {
                                if (i !== j && i !== k && j !== k) {
                                    const comboValue = `${units[i]},${units[j]},${units[k]}`;
                                    if (comboValue !== standardOrder.join(',')) {
                                        const option = document.createElement('option');
                                        option.value = comboValue;
                                        option.textContent = comboValue;
                                        unitComboSelect.appendChild(option);
                                    }
                                }
                            }
                        }
                    }
                }
            }

            unitComboSelect.addEventListener('change', function() {
                const unitCombo = this.value;
                if (!unitCombo) return;

                const ratioValue = unitRatioInput.value.trim();
                if (!ratioValue) return;

                const ratioNumbers = ratioValue.split(',').map(n => parseInt(n));
                const units = unitCombo.split(',');

                if (units.length === 2 && ratioNumbers.length === 2) {
                    addUnitRatio(units[0], units[1], ratioNumbers[0], ratioNumbers[1]);
                } else if (units.length === 3 && ratioNumbers.length === 3) {
                    addUnitRatio(units[0], units[1], ratioNumbers[0], ratioNumbers[1]);
                    const combinedRatio = ratioNumbers[1] * ratioNumbers[2];
                    addUnitRatio(units[0], units[2], ratioNumbers[0], combinedRatio);
                }

                unitRatioInput.value = '';
                unitComboSelect.value = '';
                unitComboSelect.style.display = 'none';
            });

            function addUnitRatio(unit1, unit2, num1, num2) {
                const newRatio = {
                    unit1,
                    unit2,
                    num1,
                    num2
                };
                unitRatios.push(newRatio);
                findBaseUnitAndUpdateRatios();
                updateUnitRatiosData();
                updateUnitRatiosList();
                unitRatioInput.disabled = true;
                unitRatioInput.placeholder = "请先删除现有单位配比";
            }

            function findBaseUnitAndUpdateRatios() {
                if (unitRatios.length === 0) return;
                const latestRatio = unitRatios[unitRatios.length - 1];
                const baseUnit = latestRatio.unit1;
                unitSelect.value = baseUnit;
                unitDisplay.textContent = baseUnit;
                updatePriceStrategyTable(baseUnit);
            }

            function updateUnitRatiosData() {
                const baseUnit = unitSelect.value;
                const apiData = [];

                if (baseUnit && unitRatios.length > 0) {
                    unitRatios.forEach(ratio => {
                        if (ratio.unit1 === baseUnit) {
                            apiData.push({
                                baseUnit: baseUnit,
                                subUnit: ratio.unit2,
                                ratio1: ratio.num1,
                                ratio2: ratio.num2
                            });
                        } else if (ratio.unit2 === baseUnit) {
                            apiData.push({
                                baseUnit: baseUnit,
                                subUnit: ratio.unit1,
                                ratio1: ratio.num2,
                                ratio2: ratio.num1
                            });
                        }
                    });
                }
                unitRatiosData.value = JSON.stringify(apiData);
            }

            function updateUnitRatiosList() {
                unitRatiosContainer.innerHTML = '';
                const baseUnit = unitSelect.value;
                removeAllSubUnitRows();
                const threeUnitRelationship = findThreeUnitRelationship();

                if (threeUnitRelationship) {
                    displayThreeUnitRelationship(threeUnitRelationship);
                } else {
                    unitRatios.forEach((ratio, index) => {
                        displayTwoUnitRelationship(ratio, index);
                    });
                }
            }

            function findThreeUnitRelationship() {
                if (unitRatios.length < 2) return null;
                const baseUnit = unitSelect.value;
                const related = unitRatios.filter(ratio => ratio.unit1 === baseUnit);

                if (related.length >= 2) {
                    return {
                        baseUnit: baseUnit,
                        midUnit: related[0].unit2,
                        smallUnit: related[1].unit2,
                        ratio1: related[0].num1,
                        ratio2: related[0].num2,
                        ratio3: related[1].num2
                    };
                }
                return null;
            }

            function displayThreeUnitRelationship(relation) {
                const {
                    baseUnit,
                    midUnit,
                    smallUnit,
                    ratio1,
                    ratio2,
                    ratio3
                } = relation;
                const ratioItem = document.createElement('div');
                ratioItem.className = 'unit-ratio-item';
                const ratioText = `${baseUnit},${midUnit},${smallUnit}(${ratio1}:${ratio2}:${ratio3})`;
                const ratioSpan = document.createElement('span');
                ratioSpan.innerHTML = ratioText;
                const deleteBtn = document.createElement('button');
                deleteBtn.type = 'button';
                deleteBtn.className = 'delete-ratio';
                deleteBtn.innerHTML = '×';
                deleteBtn.title = '删除此配比';

                deleteBtn.addEventListener('click', function() {
                    unitRatios = [];
                    unitDisplay.textContent = '';
                    unitSelect.value = '';
                    updatePriceStrategyTable('');
                    updateUnitRatiosData();
                    updateUnitRatiosList();
                    unitRatioInput.disabled = false;
                    unitRatioInput.placeholder = "输入如 1,20,30";
                });

                ratioItem.appendChild(ratioSpan);
                ratioItem.appendChild(deleteBtn);
                unitRatiosContainer.appendChild(ratioItem);
                addSubUnitRow(midUnit, ratio1, ratio2, baseUnit, 0);
                addSubUnitRow(smallUnit, ratio1, ratio3, baseUnit, 1);
            }

            function displayTwoUnitRelationship(ratio, index) {
                const ratioItem = document.createElement('div');
                ratioItem.className = 'unit-ratio-item';
                let ratioText, subUnit, num1, num2;
                const baseUnit = unitSelect.value;

                if (ratio.unit1 === baseUnit) {
                    ratioText = `${ratio.unit1},${ratio.unit2}(${ratio.num1}:${ratio.num2})`;
                    subUnit = ratio.unit2;
                    num1 = ratio.num1;
                    num2 = ratio.num2;
                } else if (ratio.unit2 === baseUnit) {
                    ratioText = `${ratio.unit2},${ratio.unit1}(${ratio.num2}:${ratio.num1})`;
                    subUnit = ratio.unit1;
                    num1 = ratio.num2;
                    num2 = ratio.num1;
                } else {
                    ratioText = `${ratio.unit2},${ratio.unit1}(${ratio.num1}:${ratio.num2})`;
                    subUnit = ratio.unit2;
                    num1 = ratio.num1;
                    num2 = ratio.num2;
                }

                const ratioSpan = document.createElement('span');
                ratioSpan.innerHTML = ratioText;
                const deleteBtn = document.createElement('button');
                deleteBtn.type = 'button';
                deleteBtn.className = 'delete-ratio';
                deleteBtn.innerHTML = '×';
                deleteBtn.title = '删除此配比';
                deleteBtn.dataset.index = index;

                deleteBtn.addEventListener('click', function() {
                    const idx = parseInt(this.dataset.index);
                    unitRatios.splice(idx, 1);
                    if (unitRatios.length > 0) {
                        findBaseUnitAndUpdateRatios();
                    } else {
                        unitDisplay.textContent = '';
                        unitSelect.value = '';
                        updatePriceStrategyTable('');
                        unitRatioInput.disabled = false;
                        unitRatioInput.placeholder = "输入如 1,20,30";
                    }
                    updateUnitRatiosData();
                    updateUnitRatiosList();
                });

                ratioItem.appendChild(ratioSpan);
                ratioItem.appendChild(deleteBtn);
                unitRatiosContainer.appendChild(ratioItem);
                addSubUnitRow(subUnit, num1, num2, baseUnit, index);
            }

            function updatePriceStrategyTable(baseUnit) {
                if (!baseUnit) baseUnit = '';
                baseUnitCell.textContent = baseUnit;
                baseUnitName.textContent = baseUnit;
            }

            function addSubUnitRow(subUnit, num1, num2, baseUnit, index) {
                const trId = `sub-unit-row-${index}`;
                let row = document.getElementById(trId);
                if (!row) {
                    row = document.createElement('tr');
                    row.id = trId;
                    priceStrategyTable.querySelector('tbody').appendChild(row);
                }

                row.innerHTML = `
                    <td>副单位${index + 1}</td>
                    <td>${subUnit}</td>
                    <td>1${subUnit}=${num2}${baseUnit}</td>
                    <td><input type="text" name="sub_barcode_${index}" value=""></td>
                    <td><input type="number" step="0.01" name="sub_retail_price_${index}" class="unit-price" data-ratio="${num2}" data-base-price-field="retail_price"></td>
                    <td><input type="number" step="0.01" name="sub_wholesale_price_${index}" class="unit-price" data-ratio="${num2}" data-base-price-field="wholesale_price"></td>
                    <td><input type="number" step="0.01" name="sub_vip_price_${index}" class="unit-price" data-ratio="${num2}" data-base-price-field="vip_price"></td>
                    <td><input type="number" step="0.01" name="sub_discount1_${index}" value="${document.querySelector('input[name="discount1"]').value || 0}" class="unit-discount" data-base-discount-field="discount1"></td>
                    <td><input type="number" step="0.01" name="sub_discount2_${index}" value="${document.querySelector('input[name="discount2"]').value || 0}" class="unit-discount" data-base-discount-field="discount2"></td>
                `;

                attachUnitPriceHandlers(row);
                attachDiscountHandlers(row);
            }

            function removeAllSubUnitRows() {
                const tbody = priceStrategyTable.querySelector('tbody');
                const rows = tbody.querySelectorAll('tr[id^="sub-unit-row-"]');
                rows.forEach(row => row.remove());
            }

            function attachUnitPriceHandlers(row) {
                const inputs = row.querySelectorAll('.unit-price');
                inputs.forEach(input => {
                    const baseField = input.dataset.basePriceField;
                    const ratio = parseFloat(input.dataset.ratio);
                    const baseInput = document.querySelector(`input[name="${baseField}"]`);

                    if (baseInput) {
                        baseInput.addEventListener('input', function() {
                            if (this.value) {
                                const basePrice = parseFloat(this.value);
                                input.value = (basePrice * ratio).toFixed(2);
                            }
                        });

                        if (baseInput.value) {
                            const basePrice = parseFloat(baseInput.value);
                            input.value = (basePrice * ratio).toFixed(2);
                        }

                        input.addEventListener('input', function() {
                            if (this.value) {
                                const subPrice = parseFloat(this.value);
                                baseInput.value = (subPrice / ratio).toFixed(2);
                            }
                        });
                    }
                });
            }

            function attachDiscountHandlers(row) {
                const discountInputs = row.querySelectorAll('.unit-discount');
                discountInputs.forEach(input => {
                    const baseDiscountField = input.dataset.baseDiscountField;
                    const baseDiscountInput = document.querySelector(`input[name="${baseDiscountField}"]`);

                    if (baseDiscountInput) {
                        baseDiscountInput.addEventListener('input', function() {
                            input.value = this.value;
                        });

                        input.addEventListener('input', function() {
                            baseDiscountInput.value = this.value;
                            document.querySelectorAll(`input[data-base-discount-field="${baseDiscountField}"]`)
                                .forEach(el => {
                                    if (el !== input) el.value = this.value;
                                });
                        });
                    }
                });
            }

            window.updatePriceStrategyTable = updatePriceStrategyTable;
            updatePriceStrategyTable(unitSelect.value);
        }

        function initUnitAutoFill() {
            const unitSelect = document.querySelector('select[name="unit"]');
            const multiUnitCheckbox = document.querySelector('input[name="multi_unit"]');
            const preferredInUnitSelect = document.querySelector('select[name="preferred_in_unit"]');
            const preferredOutUnitSelect = document.querySelector('select[name="preferred_out_unit"]');

            unitSelect.addEventListener('change', function() {
                if (!multiUnitCheckbox.checked) {
                    const selectedUnit = this.value;
                    if (selectedUnit) {
                        preferredInUnitSelect.value = selectedUnit;
                        preferredOutUnitSelect.value = selectedUnit;
                    }
                }

                if (window.updatePriceStrategyTable) {
                    window.updatePriceStrategyTable(this.value);
                }
            });
        }

        document.getElementById('response-frame').onload = function() {
            try {
                var response = this.contentWindow.document.body.innerHTML;
                const batchAddChecked = document.getElementById('batch_add').checked;

                if (response && response.includes('✅')) {
                    if (batchAddChecked) {
                        const successMessage = response.includes(':') ? response : '添加成功';
                        const form = document.querySelector('form');
                        form.reset();
                        document.getElementById('batch_add').checked = true;
                        document.getElementById('image-preview-container').innerHTML = '';
                        showMessage(successMessage);
                        
                        // 清除Redis缓存
                        fetch('clear_product_cache.php')
                            .then(response => response.json())
                            .then(data => {
                                if (data.success) {
                                    console.log('Redis缓存已清除: ' + data.message);
                                }
                            })
                            .catch(error => console.error('清除缓存失败:', error));
                        
                        // 滚动到页面顶部
                        window.scrollTo({
                            top: 0,
                            behavior: 'smooth'
                        });

                        // 获取新的商品编号（保持原有代码）
                        fetch('get_next_product_code.php')
                            .then(response => {
                                if (!response.ok) {
                                    throw new Error('获取商品编号失败');
                                }
                                return response.text();
                            })
                            .then(code => {
                                if (code && code.trim()) {
                                    document.getElementsByName('product_code')[0].value = code.trim();
                                } else {
                                    showMessage('获取商品编号失败：返回数据为空');
                                }
                            })
                            .catch(error => {
                                console.error('获取商品编号失败:', error);
                                showMessage('获取商品编号失败，请刷新页面重试');
                            });
                    } else {
                        window.location.href = 'list_products.php?message=添加成功&refresh=1';
                    }
                } else if (response && response.includes('❌')) {
                    const errorMessage = response.replace('❌ 错误: ', '');
                    alert('保存失败: ' + errorMessage);
                }
            } catch (e) {
                // 可能出现跨域错误，忽略
            }
        };

        document.getElementById('product-images').addEventListener('change', function() {
            const container = document.getElementById('image-preview-container');
            container.innerHTML = '';
            deletedImageIndexes = []; // 重置已删除图片索引

            if (this.files.length > 0) {
                const maxFiles = 20;
                const filesToProcess = Math.min(this.files.length, maxFiles);

                for (let i = 0; i < filesToProcess; i++) {
                    const file = this.files[i];
                    if (!file.type.match('image.*')) continue;

                    const reader = new FileReader();
                    reader.onload = (function(file, index) {
                        return function(e) {
                            const div = document.createElement('div');
                            div.className = 'image-item temp-image';
                            div.dataset.index = index; // 添加索引属性

                            const img = document.createElement('img');
                            img.src = e.target.result;
                            img.className = 'preview-image';
                            img.alt = '预览图片';

                            if (index === 0) {
                                const span = document.createElement('span');
                                span.className = 'main-label';
                                span.textContent = '主图';
                                div.appendChild(span);
                            }

                            const button = document.createElement('button');
                            button.type = 'button';
                            button.className = 'delete-image';
                            button.textContent = '×';
                            button.title = '移除图片';
                            button.onclick = function() {
                                div.remove();
                                // 清除文件输入框的值
                                document.getElementById('product-images').value = '';
                            };

                            div.appendChild(img);
                            div.appendChild(button);
                            container.appendChild(div);
                        };
                    })(file, i);

                    reader.readAsDataURL(file);
                }
            }
        });

        // 删除现有图片功能
        const container = document.getElementById('image-preview-container');
        if (container) {
            container.addEventListener('click', function(e) {
                if (e.target.classList.contains('delete-image')) {
                    const button = e.target;
                    const imageItem = button.closest('.image-item');
                    const imageId = button.dataset.imageId;

                    if (imageId) {
                        // 询问用户是否确认删除
                        if (confirm('确定要删除此图片吗？此操作无法撤销')) {
                            // 使用AJAX删除图片
                            const formData = new FormData();
                            formData.append('image_id', imageId);

                            fetch('delete_image.php', {
                                    method: 'POST',
                                    body: formData
                                })
                                .then(response => {
                                    if (!response.ok) {
                                        throw new Error('网络响应异常');
                                    }
                                    return response.json();
                                })
                                .then(data => {
                                    if (data.status === 'success') {
                                        // 删除成功，移除预览
                                        imageItem.remove();
                                        // 清除文件输入框的值
                                        document.getElementById('product-images').value = '';
                                        showMessage('图片已删除');
                                    } else {
                                        showMessage('删除失败：' + data.message);
                                    }
                                })
                                .catch(error => {
                                    console.error('删除请求出错:', error);
                                    showMessage('删除请求失败，请稍后重试');
                                });
                        }
                    } else {
                        // 临时图片直接移除，并记录索引
                        const index = parseInt(imageItem.dataset.index);
                        if (!isNaN(index) && !deletedImageIndexes.includes(index)) {
                            deletedImageIndexes.push(index);
                        }
                        imageItem.remove();
                        // 清除文件输入框的值
                        document.getElementById('product-images').value = '';
                    }
                }
            });
        }

        document.querySelector('button[type="reset"]').addEventListener('click', function() {
            document.getElementById('image-preview-container').innerHTML = '';
        });
    </script>
</body>

</html>