<?php
// 引入数据库配置文件
require_once '../config.php';

// 设置响应头为JSON
header('Content-Type: application/json');

// 数据库连接
$conn = get_db_connection();

// 检查是否接收到图片ID
if (!isset($_POST['image_id']) || !is_numeric($_POST['image_id'])) {
    echo json_encode(['status' => 'error', 'message' => '无效的图片ID']);
    exit;
}

$image_id = (int)$_POST['image_id'];
$product_id = 0;

// 查询图片信息，包括文件路径和所属产品ID
$stmt = $conn->prepare("SELECT product_id, file_path, is_main FROM product_images WHERE id = ?");
$stmt->bind_param("i", $image_id);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows === 0) {
    echo json_encode(['status' => 'error', 'message' => '图片不存在']);
    exit;
}

$image = $result->fetch_assoc();
$product_id = $image['product_id'];
$is_main = $image['is_main'];
$file_path = $image['file_path'];

// 开始事务
$conn->begin_transaction();

try {
    // 删除数据库中的图片记录
    $stmt = $conn->prepare("DELETE FROM product_images WHERE id = ?");
    $stmt->bind_param("i", $image_id);

    if (!$stmt->execute()) {
        throw new Exception("删除图片记录失败");
    }

    // 如果删除的是主图，需要设置新的主图
    if ($is_main) {
        // 查找该产品的另一张图片设置为主图
        $stmt = $conn->prepare("SELECT id FROM product_images WHERE product_id = ? LIMIT 1");
        $stmt->bind_param("i", $product_id);
        $stmt->execute();
        $result = $stmt->get_result();

        if ($result->num_rows > 0) {
            $new_main_id = $result->fetch_assoc()['id'];
            $stmt = $conn->prepare("UPDATE product_images SET is_main = 1 WHERE id = ?");
            $stmt->bind_param("i", $new_main_id);

            if (!$stmt->execute()) {
                throw new Exception("更新主图失败");
            }
        }
    }

    // 提交事务
    $conn->commit();

    // 尝试删除物理文件
    $actual_path = __DIR__ . '/' . str_replace('../', '', $file_path);
    if (file_exists($actual_path)) {
        unlink($actual_path);
    }

    echo json_encode(['status' => 'success', 'message' => '图片删除成功']);
} catch (Exception $e) {
    // 回滚事务
    $conn->rollback();
    echo json_encode(['status' => 'error', 'message' => $e->getMessage()]);
}

$stmt->close();
$conn->close();
