<?php
// save_user.php
session_start();
if (!isset($_SESSION['user']) || $_SESSION['user']['role'] !== 'admin') {
    exit('❌ 权限不足');
}

// 引入数据库配置文件
require_once '../config.php';

// 数据库连接
$conn = get_db_connection();

// 获取表单数据
$username = trim($_POST['username'] ?? '');
$password = $_POST['password'] ?? '';
$real_name = $_POST['real_name'] ?? '';
$role = $_POST['role'] ?? 'user';
$email = $_POST['email'] ?? '';
$phone = $_POST['phone'] ?? '';
$is_active = isset($_POST['is_active']) ? 1 : 0;

// 校验必填项
if (empty($username) || empty($password) || empty($role)) {
    exit('❌ 用户名、密码、角色不能为空');
}

// 检查用户名是否已存在
$check = $conn->prepare("SELECT id FROM users WHERE username = ?");
$check->bind_param("s", $username);
$check->execute();
$check->store_result();
if ($check->num_rows > 0) {
    exit('❌ 用户名已存在');
}
$check->close();

// 加密密码
$hashedPassword = password_hash($password, PASSWORD_DEFAULT);

// 插入用户
$stmt = $conn->prepare("
    INSERT INTO users (username, password, real_name, role, email, phone, is_active)
    VALUES (?, ?, ?, ?, ?, ?, ?)
");
$stmt->bind_param("ssssssi", $username, $hashedPassword, $real_name, $role, $email, $phone, $is_active);

if ($stmt->execute()) {
    // 添加成功后重定向到用户列表页面
    echo "<script>window.parent.location.href = 'list_users.php?message=用户 {$username} 添加成功';</script>";
    exit;
} else {
    echo "❌ 数据库错误: " . $stmt->error;
}

$stmt->close();
$conn->close();
